@@ -23,7 +23,7 @@
 #include "kis_types.h"
 
 #include "kis_stroke_job_strategy.h"
-#include "kis_image_signal_router.h"
+#include "KisImageSignals.h"
 #include "kundo2magicstring.h"
 #include "kundo2commandextradata.h"
 
@@ -35,7 +35,8 @@ public:
         NONE = 0x0,
         RECURSIVE = 0x1,
         NO_UI_UPDATES = 0x2,
-        SUPPORTS_WRAPAROUND_MODE = 0x4
+        SUPPORTS_WRAPAROUND_MODE = 0x4,
+        NO_IMAGE_UPDATES = 0x8
     };
 
     Q_DECLARE_FLAGS(ProcessingFlags, ProcessingFlag)
