@@ -864,7 +864,7 @@ void KisLazyBrushTest::testCutOnGraph()
 
         qDebug() << ppVar(aLabelImage.offset());
     }
-    QImage bLabelImage(bLabelRect.size(), QImage::Format_ARGB32);;
+    QImage bLabelImage(bLabelRect.size(), QImage::Format_ARGB32);
     {
         QPainter gc(&bLabelImage);
         gc.fillRect(QRect(QPoint(), bLabelRect.size()), Qt::red);
@@ -1211,6 +1211,7 @@ void KisLazyBrushTest::testCutOnGraphDevice()
 }
 
 #include "lazybrush/kis_multiway_cut.h"
+#include "testing_timed_default_bounds.h"
 
 void KisLazyBrushTest::testCutOnGraphDeviceMulti()
 {
@@ -1223,8 +1224,11 @@ void KisLazyBrushTest::testCutOnGraphDeviceMulti()
     KisPaintDeviceSP dLabelDev = loadTestImage("fill4_d.png", true);
     KisPaintDeviceSP eLabelDev = loadTestImage("fill4_e.png", true);
 
-
     KisPaintDeviceSP filteredMainDev = KisPainter::convertToAlphaAsGray(mainDev);
+    KisDefaultBoundsBaseSP bounds = new TestUtil::TestingTimedDefaultBounds(mainDev->exactBounds());
+    mainDev->setDefaultBounds(bounds);
+    filteredMainDev->setDefaultBounds(bounds);
+
     const QRect filterRect = filteredMainDev->exactBounds();
     KisGaussianKernel::applyLoG(filteredMainDev,
                                 filterRect,
@@ -1270,6 +1274,11 @@ void KisLazyBrushTest::testLoG()
     // mainDev->fill(fillRect, fg);
 
     KisPaintDeviceSP filteredMainDev = KisPainter::convertToAlphaAsGray(mainDev);
+
+    KisDefaultBoundsBaseSP bounds = new TestUtil::TestingTimedDefaultBounds(mainDev->exactBounds());
+    mainDev->setDefaultBounds(bounds);
+    filteredMainDev->setDefaultBounds(bounds);
+
     KisGaussianKernel::applyLoG(filteredMainDev,
                                 rect,
                                 4.0,
