@@ -391,23 +391,23 @@ struct KisStrokesQueueTest::LodStrokesQueueTester {
           realContext(2),
           context(!real ? fakeContext : realContext)
     {
-        queue.setSuspendUpdatesStrokeStrategyFactory(
+        queue.setSuspendResumeUpdatesStrokeStrategyFactory(
             []() {
-                return KisSuspendResumePair(
+                KisSuspendResumePair suspend(
                     new KisTestingStrokeStrategy("susp_u_", false, true, true),
                     QList<KisStrokeJobData*>());
-            });
 
-        queue.setResumeUpdatesStrokeStrategyFactory(
-            []() {
-                return KisSuspendResumePair(
+                KisSuspendResumePair resume(
                     new KisTestingStrokeStrategy("resu_u_", false, true, true),
                     QList<KisStrokeJobData*>());
+
+                return std::make_pair(suspend, resume);
             });
+
         queue.setLod0ToNStrokeStrategyFactory(
-            [](bool forgettable) {
+            [] (bool forgettable) {
                 Q_UNUSED(forgettable);
-                return KisSuspendResumePair(
+                return KisLodSyncPair(
                     new KisTestingStrokeStrategy("sync_u_", false, true, true),
                     QList<KisStrokeJobData*>());
             });
@@ -802,7 +802,6 @@ void KisStrokesQueueTest::testUniquelyConcurrentJobs()
     KisStrokeId id1 = queue.startStroke(new KisTestingStrokeStrategy("str1_", false, true));
     queue.addJob(id1, new KisTestingStrokeJobData(KisStrokeJobData::CONCURRENT));
     queue.addJob(id1, new KisTestingStrokeJobData(KisStrokeJobData::CONCURRENT));
-    queue.endStroke(id1);
 
     { // manual test
         t.processQueue();
@@ -832,6 +831,8 @@ void KisStrokesQueueTest::testUniquelyConcurrentJobs()
     checkJobsOverlapping(t, id1, KisStrokeJobData::UNIQUELY_CONCURRENT, KisStrokeJobData::UNIQUELY_CONCURRENT, false);
     checkJobsOverlapping(t, id1, KisStrokeJobData::SEQUENTIAL, KisStrokeJobData::UNIQUELY_CONCURRENT, false);
     checkJobsOverlapping(t, id1, KisStrokeJobData::BARRIER, KisStrokeJobData::UNIQUELY_CONCURRENT, false);
+
+    queue.endStroke(id1);
 }
 
 
