@@ -264,7 +264,10 @@ bool saveResourceToStore(KoResource *resource, KoStore *store, const QString &re
         warnKrita << "Could not open buffer";
         return false;
     }
-    Q_ASSERT(!store->hasFile(resType + "/" + resource->shortFilename()));
+    if(!store->hasFile(resType + "/" + resource->shortFilename())) {
+        warnKrita << "Store does not have file" << (resType + "/" + resource->shortFilename());
+        return false;
+    }
     if (!store->open(resType + "/" + resource->shortFilename())) {
         warnKrita << "Could not open file in store for resource";
         return false;
@@ -280,7 +283,7 @@ bool KisResourceBundle::save()
 {
     if (filename().isEmpty()) return false;
 
-    addMeta("updated", QDate::currentDate().toString("dd/MM/yyyy"));
+    addMeta("updated", QDateTime::currentDateTime().toOffsetFromUtc(0).toString(Qt::ISODate));
 
     QDir bundleDir = KoResourcePaths::saveLocation("data", "bundles");
     bundleDir.cdUp();
@@ -1046,7 +1049,7 @@ void KisResourceBundle::recreateBundle(QScopedPointer<KoStore> &oldStore)
         KoHashGenerator *generator = KoHashGeneratorProvider::instance()->getGenerator("MD5");
         KisResourceBundleManifest newManifest;
 
-        addMeta("updated", QDate::currentDate().toString("dd/MM/yyyy"));
+        addMeta("updated", QDateTime::currentDateTime().toString(Qt::ISODate));
 
         Q_FOREACH (KisResourceBundleManifest::ResourceReference ref, m_manifest.files()) {
             // Wrong manifest entry found, skip it
