@@ -25,7 +25,7 @@
 #include "dcolorreset.xpm"
 
 #include <QColorDialog>
-#include "dialogs/kis_dlg_internal_color_selector.h"
+#include "KisDlgInternalColorSelector.h"
 
 #include "kis_signals_blocker.h"
 
@@ -38,7 +38,7 @@
 
 class Q_DECL_HIDDEN KoDualColorButton::Private
 {
-  public:
+public:
     Private(const KoColor &fgColor, const KoColor &bgColor,
             QWidget *_dialogParent,
             const KoColorDisplayRendererInterface *_displayRenderer)
@@ -61,7 +61,7 @@ class Q_DECL_HIDDEN KoDualColorButton::Private
         arrowBitmap.fill(Qt::transparent);
 
         QPainter p(&arrowBitmap);
-        p.setPen(dialogParent->palette().foreground().color());
+        p.setPen(dialogParent->palette().windowText().color());
 
         // arrow pointing left
         p.drawLine(0, 3, 7, 3);
@@ -98,7 +98,7 @@ void KoDualColorButton::Private::init(KoDualColorButton *q)
         q->setMinimumSize( q->sizeHint() );
 
     q->setAcceptDrops( true );
-    QString caption = i18n("Select a color");
+    QString caption = i18n("Select a Color");
     KisDlgInternalColorSelector::Config config = KisDlgInternalColorSelector::Config();
     config.modal = false;
     colorSelectorDialog = new KisDlgInternalColorSelector(q, foregroundColor, config, caption, displayRenderer);
@@ -128,47 +128,47 @@ KoDualColorButton::KoDualColorButton(const KoColor &foregroundColor, const KoCol
 
 KoDualColorButton::~KoDualColorButton()
 {
-  delete d;
+    delete d;
 }
 
 KoColor KoDualColorButton::foregroundColor() const
 {
-  return d->foregroundColor;
+    return d->foregroundColor;
 }
 
 KoColor KoDualColorButton::backgroundColor() const
 {
-  return d->backgroundColor;
+    return d->backgroundColor;
 }
 
 bool KoDualColorButton::popDialog() const
 {
-  return d->popDialog;
+    return d->popDialog;
 }
 
 QSize KoDualColorButton::sizeHint() const
 {
-  return QSize( 34, 34 );
+    return QSize( 34, 34 );
 }
 
-void KoDualColorButton::setForegroundColor( const KoColor &color )
+void KoDualColorButton::setForegroundColor(const KoColor &color)
 {
-  d->foregroundColor = color;
-  {
-      /**
+    d->foregroundColor = color;
+    {
+        /**
        * The internal color selector might emit the color of a different profile, so
        * we should break this cycling dependency somehow.
        */
-      KisSignalsBlocker b(d->colorSelectorDialog);
-      d->colorSelectorDialog->slotColorUpdated(color);
-  }
-  repaint();
+        KisSignalsBlocker b(d->colorSelectorDialog);
+        d->colorSelectorDialog->slotColorUpdated(color);
+    }
+    repaint();
 }
 
 void KoDualColorButton::setBackgroundColor( const KoColor &color )
 {
-  d->backgroundColor = color;
-  repaint();
+    d->backgroundColor = color;
+    repaint();
 }
 
 void KoDualColorButton::setDisplayRenderer(const KoColorDisplayRendererInterface *displayRenderer)
@@ -201,49 +201,49 @@ QColor KoDualColorButton::getColorFromDisplayRenderer(KoColor c)
 
 void KoDualColorButton::setPopDialog( bool popDialog )
 {
-  d->popDialog = popDialog;
+    d->popDialog = popDialog;
 }
 
 void KoDualColorButton::metrics( QRect &foregroundRect, QRect &backgroundRect )
 {
-  foregroundRect = QRect( 0, 0, width() - 14, height() - 14 );
-  backgroundRect = QRect( 14, 14, width() - 14, height() - 14 );
+    foregroundRect = QRect( 0, 0, width() - 14, height() - 14 );
+    backgroundRect = QRect( 14, 14, width() - 14, height() - 14 );
 }
 
 void KoDualColorButton::paintEvent(QPaintEvent *)
 {
-  QRect foregroundRect;
-  QRect backgroundRect;
+    QRect foregroundRect;
+    QRect backgroundRect;
 
-  QPainter painter( this );
+    QPainter painter( this );
 
-  metrics( foregroundRect, backgroundRect );
+    metrics( foregroundRect, backgroundRect );
 
-  QBrush defBrush = palette().brush( QPalette::Button );
-  QBrush foregroundBrush( getColorFromDisplayRenderer(d->foregroundColor), Qt::SolidPattern );
-  QBrush backgroundBrush( getColorFromDisplayRenderer(d->backgroundColor), Qt::SolidPattern );
+    QBrush defBrush = palette().brush( QPalette::Button );
+    QBrush foregroundBrush( getColorFromDisplayRenderer(d->foregroundColor), Qt::SolidPattern );
+    QBrush backgroundBrush( getColorFromDisplayRenderer(d->backgroundColor), Qt::SolidPattern );
 
-  qDrawShadeRect( &painter, backgroundRect, palette(), false, 1, 0,
-                  isEnabled() ? &backgroundBrush : &defBrush );
+    qDrawShadeRect( &painter, backgroundRect, palette(), false, 1, 0,
+                    isEnabled() ? &backgroundBrush : &defBrush );
 
-  qDrawShadeRect( &painter, foregroundRect, palette(), false, 1, 0,
-                  isEnabled() ? &foregroundBrush : &defBrush );
+    qDrawShadeRect( &painter, foregroundRect, palette(), false, 1, 0,
+                    isEnabled() ? &foregroundBrush : &defBrush );
 
-  painter.setPen( palette().color( QPalette::Shadow ) );
+    painter.setPen( palette().color( QPalette::Shadow ) );
 
-  painter.drawPixmap( foregroundRect.right() + 2, 1, d->arrowBitmap );
-  painter.drawPixmap( 1, foregroundRect.bottom() + 2, d->resetPixmap );
+    painter.drawPixmap( foregroundRect.right() + 2, 1, d->arrowBitmap );
+    painter.drawPixmap( 1, foregroundRect.bottom() + 2, d->resetPixmap );
 }
 
 void KoDualColorButton::dragEnterEvent( QDragEnterEvent *event )
 {
-  event->setAccepted( isEnabled() && KColorMimeData::canDecode( event->mimeData() ) );
+    event->setAccepted( isEnabled() && KColorMimeData::canDecode( event->mimeData() ) );
 }
 
 void KoDualColorButton::dropEvent( QDropEvent *event )
 {
     Q_UNUSED(event);
-/*  QColor color = KColorMimeData::fromMimeData( event->mimeData() );
+    /*  QColor color = KColorMimeData::fromMimeData( event->mimeData() );
 
   if ( color.isValid() ) {
     if ( d->selection == Foreground ) {
@@ -268,63 +268,63 @@ void KoDualColorButton::slotSetForeGroundColorFromDialog(const KoColor color)
 
 void KoDualColorButton::mousePressEvent( QMouseEvent *event )
 {
-  QRect foregroundRect;
-  QRect backgroundRect;
+    QRect foregroundRect;
+    QRect backgroundRect;
 
-  metrics( foregroundRect, backgroundRect );
+    metrics( foregroundRect, backgroundRect );
 
-  d->dragPosition = event->pos();
+    d->dragPosition = event->pos();
 
-  d->dragFlag = false;
+    d->dragFlag = false;
 
-  if ( foregroundRect.contains( d->dragPosition ) ) {
-    d->tmpSelection = Foreground;
-    d->miniCtlFlag = false;
-  }
-  else if( backgroundRect.contains( d->dragPosition ) ) {
-    d->tmpSelection = Background;
-    d->miniCtlFlag = false;
-  }
-  else if ( event->pos().x() > foregroundRect.width() ) {
-    // We handle the swap and reset controls as soon as the mouse is
-    // is pressed and ignore further events on this click (mosfet).
+    if ( foregroundRect.contains( d->dragPosition ) ) {
+        d->tmpSelection = Foreground;
+        d->miniCtlFlag = false;
+    }
+    else if( backgroundRect.contains( d->dragPosition ) ) {
+        d->tmpSelection = Background;
+        d->miniCtlFlag = false;
+    }
+    else if ( event->pos().x() > foregroundRect.width() ) {
+        // We handle the swap and reset controls as soon as the mouse is
+        // is pressed and ignore further events on this click (mosfet).
 
-    KoColor tmp = d->foregroundColor;
-    d->foregroundColor = d->backgroundColor;
-    d->backgroundColor = tmp;
+        KoColor tmp = d->foregroundColor;
+        d->foregroundColor = d->backgroundColor;
+        d->backgroundColor = tmp;
 
-    emit backgroundColorChanged( d->backgroundColor );
-    emit foregroundColorChanged( d->foregroundColor );
+        emit backgroundColorChanged( d->backgroundColor );
+        emit foregroundColorChanged( d->foregroundColor );
 
-    d->miniCtlFlag = true;
-  }
-  else if ( event->pos().x() < backgroundRect.x() ) {
-    d->foregroundColor = d->displayRenderer->approximateFromRenderedQColor(Qt::black);
-    d->backgroundColor = d->displayRenderer->approximateFromRenderedQColor(Qt::white);
+        d->miniCtlFlag = true;
+    }
+    else if ( event->pos().x() < backgroundRect.x() ) {
+        d->foregroundColor = d->displayRenderer->approximateFromRenderedQColor(Qt::black);
+        d->backgroundColor = d->displayRenderer->approximateFromRenderedQColor(Qt::white);
 
-    emit backgroundColorChanged( d->backgroundColor );
-    emit foregroundColorChanged( d->foregroundColor );
+        emit backgroundColorChanged( d->backgroundColor );
+        emit foregroundColorChanged( d->foregroundColor );
 
-    d->miniCtlFlag = true;
-  }
-  repaint();
+        d->miniCtlFlag = true;
+    }
+    repaint();
 }
 
 
 void KoDualColorButton::mouseMoveEvent( QMouseEvent *event )
 {
-  if ( !d->miniCtlFlag ) {
-    int delay = QApplication::startDragDistance();
+    if ( !d->miniCtlFlag ) {
+        int delay = QApplication::startDragDistance();
 
-    if ( event->x() >= d->dragPosition.x() + delay || event->x() <= d->dragPosition.x() - delay ||
-         event->y() >= d->dragPosition.y() + delay || event->y() <= d->dragPosition.y() - delay ) {
-      KColorMimeData::createDrag( d->tmpSelection == Foreground ?
-                                  getColorFromDisplayRenderer(d->foregroundColor) :
-                                  getColorFromDisplayRenderer(d->backgroundColor),
-                                  this )->start();
-      d->dragFlag = true;
+        if ( event->x() >= d->dragPosition.x() + delay || event->x() <= d->dragPosition.x() - delay ||
+             event->y() >= d->dragPosition.y() + delay || event->y() <= d->dragPosition.y() - delay ) {
+            KColorMimeData::createDrag( d->tmpSelection == Foreground ?
+                                            getColorFromDisplayRenderer(d->foregroundColor) :
+                                            getColorFromDisplayRenderer(d->backgroundColor),
+                                        this )->start();
+            d->dragFlag = true;
+        }
     }
-  }
 }
 
 void KoDualColorButton::mouseReleaseEvent( QMouseEvent *event )
@@ -343,12 +343,12 @@ void KoDualColorButton::mouseReleaseEvent( QMouseEvent *event )
     if (foregroundRect.contains( event->pos())) {
         if (d->tmpSelection == Foreground) {
             if (d->popDialog) {
-#ifndef Q_OS_OSX
+#ifndef Q_OS_MACOS
                 d->colorSelectorDialog->setPreviousColor(d->foregroundColor);
-                //this should toggle, but I don't know how to implement that...
+                // this should toggle, but I don't know how to implement that...
                 d->colorSelectorDialog->show();
 #else
-                QColor c = d->displayRenderer->toQColor(d->foregroundColor);
+                QColor c = d->foregroundColor.toQColor();
                 c = QColorDialog::getColor(c, this);
                 if (c.isValid()) {
                     d->foregroundColor = d->displayRenderer->approximateFromRenderedQColor(c);
@@ -356,24 +356,22 @@ void KoDualColorButton::mouseReleaseEvent( QMouseEvent *event )
                 }
 #endif
             }
-            else {
-                emit pleasePopDialog(d->foregroundColor);
-            }
         }
         else {
             d->foregroundColor = d->backgroundColor;
             emit foregroundColorChanged( d->foregroundColor );
         }
-    } else if ( backgroundRect.contains( event->pos() )) {
+    }
+    else if ( backgroundRect.contains( event->pos() )) {
         if(d->tmpSelection == Background ) {
             if( d->popDialog) {
-#ifndef Q_OS_OSX
+#ifndef Q_OS_MACOS
                 KoColor c = d->backgroundColor;
-                c = KisDlgInternalColorSelector::getModalColorDialog(c, this);
+                c = KisDlgInternalColorSelector::getModalColorDialog(c, this, d->colorSelectorDialog->windowTitle());
                 d->backgroundColor = c;
                 emit backgroundColorChanged(d->backgroundColor);
 #else
-                QColor c = d->displayRenderer->toQColor(d->backgroundColor);
+                QColor c = d->backgroundColor.toQColor();
                 c = QColorDialog::getColor(c, this);
                 if (c.isValid()) {
                     d->backgroundColor = d->displayRenderer->approximateFromRenderedQColor(c);
@@ -381,8 +379,6 @@ void KoDualColorButton::mouseReleaseEvent( QMouseEvent *event )
                 }
 #endif
             }
-            else
-                emit pleasePopDialog( d->backgroundColor);
         } else {
             d->backgroundColor = d->foregroundColor;
             emit backgroundColorChanged( d->backgroundColor );
