@@ -34,6 +34,7 @@
 #include "kis_undo_adapter.h"
 #include "kis_node_dummies_graph.h"
 #include "kis_dummies_facade_base.h"
+#include "KisNodeDisplayModeAdapter.h"
 #include "kis_signal_compressor.h"
 #include "kis_signal_compressor_with_param.h"
 #include "kis_keyframe_channel.h"
@@ -50,7 +51,10 @@
 
 #include "kis_node_view_color_scheme.h"
 #include "krita_utils.h"
+#include "KisPart.h"
 #include <QApplication>
+#include "KisDocument.h"
+#include "KisViewManager.h"
 #include "kis_processing_applicator.h"
 #include <KisImageBarrierLockerWithFeedback.h>
 #include "kis_node_uuid_info.h"
@@ -173,7 +177,7 @@ struct TimelineFramesModel::Private
         KisNodeDummy *dummy = converter->dummyFromRow(row);
         if (!dummy) return false;
 
-        KisNodePropertyListCommand::setNodePropertiesNoUndo(dummy->node(), image, props);
+        nodeInterface->setNodeProperties(dummy->node(), image, props);
         return true;
     }
 
@@ -248,7 +252,9 @@ QMap<QString, KisKeyframeChannel*> TimelineFramesModel::channelsAt(QModelIndex i
     return srcDummy->node()->keyframeChannels();
 }
 
-void TimelineFramesModel::setDummiesFacade(KisDummiesFacadeBase *dummiesFacade, KisImageSP image)
+void TimelineFramesModel::setDummiesFacade(KisDummiesFacadeBase *dummiesFacade,
+                                           KisImageSP image,
+                                           KisNodeDisplayModeAdapter *displayModeAdapter)
 {
     KisDummiesFacadeBase *oldDummiesFacade = m_d->dummiesFacade;
 
@@ -265,7 +271,7 @@ void TimelineFramesModel::setDummiesFacade(KisDummiesFacadeBase *dummiesFacade,
     m_d->converter.reset();
 
     if (m_d->dummiesFacade) {
-        m_d->converter.reset(new TimelineNodeListKeeper(this, m_d->dummiesFacade));
+        m_d->converter.reset(new TimelineNodeListKeeper(this, m_d->dummiesFacade, displayModeAdapter));
         connect(m_d->dummiesFacade, SIGNAL(sigDummyChanged(KisNodeDummy*)),
                 SLOT(slotDummyChanged(KisNodeDummy*)));
         connect(m_d->image->animationInterface(),
@@ -308,6 +314,8 @@ void TimelineFramesModel::slotImageContentChanged()
 
 void TimelineFramesModel::processUpdateQueue()
 {
+    if (!m_d->converter) return;
+
     Q_FOREACH (KisNodeDummy *dummy, m_d->updateQueue) {
         int row = m_d->converter->rowForDummy(dummy);
 
@@ -471,7 +479,7 @@ QVariant TimelineFramesModel::headerData(int section, Qt::Orientation orientatio
             KisNodeSP node = dummy->node();
 
             QFont baseFont;
-            if (node->projectionLeaf()->isDroppedMask()) {
+            if (node->projectionLeaf()->isDroppedNode()) {
                 baseFont.setStrikeOut(true);
             } else if (m_d->image && m_d->image->isolatedModeRoot() &&
                        KisNodeModel::belongsToIsolatedGroup(m_d->image, node, m_d->dummiesFacade)) {
@@ -582,6 +590,10 @@ QMimeData *TimelineFramesModel::mimeDataExtended(const QModelIndexList &indexes,
     const int baseRow = baseIndex.row();
     const int baseColumn = baseIndex.column();
 
+    const QByteArray uuidDataRoot = m_d->image->root()->uuid().toRfc4122();
+    stream << int(uuidDataRoot.size());
+    stream.writeRawData(uuidDataRoot.data(), uuidDataRoot.size());
+
     stream << indexes.size();
     stream << baseRow << baseColumn;
 
@@ -639,6 +651,32 @@ bool TimelineFramesModel::dropMimeDataExtended(const QMimeData *data, Qt::DropAc
     QByteArray encoded = data->data("application/x-krita-frame");
     QDataStream stream(&encoded, QIODevice::ReadOnly);
 
+    int uuidLenRoot = 0;
+    stream >> uuidLenRoot;
+    QByteArray uuidDataRoot(uuidLenRoot, '\0');
+    stream.readRawData(uuidDataRoot.data(), uuidLenRoot);
+    QUuid nodeUuidRoot = QUuid::fromRfc4122(uuidDataRoot);
+
+    KisPart *partInstance = KisPart::instance();
+    QList<QPointer<KisDocument>> documents = partInstance->documents();
+
+    KisImageSP srcImage = 0;
+    Q_FOREACH(KisDocument *doc, documents) {
+        KisImageSP tmpSrcImage = doc->image();
+        if (tmpSrcImage->root()->uuid() == nodeUuidRoot) {
+            srcImage = tmpSrcImage;
+            break;
+        }
+    }
+
+    if (!srcImage) {
+        KisPart *kisPartInstance = KisPart::instance();
+        kisPartInstance->currentMainwindow()->viewManager()->showFloatingMessage(
+                    i18n("Dropped frames are not available in this Krita instance")
+                    , QIcon());
+        return false;
+    }
+
     int size, baseRow, baseColumn;
     stream >> size >> baseRow >> baseColumn;
 
@@ -663,7 +701,7 @@ bool TimelineFramesModel::dropMimeDataExtended(const QMimeData *data, Qt::DropAc
 
         if (!nodeUuid.isNull()) {
             KisNodeUuidInfo nodeInfo(nodeUuid);
-            srcNode = nodeInfo.findNode(m_d->image->root());
+            srcNode = nodeInfo.findNode(srcImage->root());
         } else {
             QModelIndex index = this->index(srcRow, srcColumn);
             srcNode = nodeAt(index);
@@ -709,7 +747,9 @@ bool TimelineFramesModel::dropMimeDataExtended(const QMimeData *data, Qt::DropAc
     }
 
     if (cmd) {
-        KisProcessingApplicator::runSingleCommandStroke(m_d->image, cmd, KisStrokeJobData::BARRIER);
+        KisProcessingApplicator::runSingleCommandStroke(m_d->image, cmd,
+                                                        KisStrokeJobData::BARRIER,
+                                                        KisStrokeJobData::EXCLUSIVE);
     }
 
     return cmd;
@@ -836,7 +876,9 @@ bool TimelineFramesModel::insertFrames(int dstColumn, const QList<int> &dstRows,
                                         newTime, parentCommand);
     }
 
-    KisProcessingApplicator::runSingleCommandStroke(m_d->image, parentCommand, KisStrokeJobData::BARRIER);
+    KisProcessingApplicator::runSingleCommandStroke(m_d->image, parentCommand,
+                                                    KisStrokeJobData::BARRIER,
+                                                    KisStrokeJobData::EXCLUSIVE);
 
     return true;
 }
@@ -934,7 +976,9 @@ bool TimelineFramesModel::insertHoldFrames(QModelIndexList selectedIndexes, int
     }
 
 
-    KisProcessingApplicator::runSingleCommandStroke(m_d->image, parentCommand.take(), KisStrokeJobData::BARRIER);
+    KisProcessingApplicator::runSingleCommandStroke(m_d->image, parentCommand.take(),
+                                                    KisStrokeJobData::BARRIER,
+                                                    KisStrokeJobData::EXCLUSIVE);
     return true;
 }
 
